@@ -10,12 +10,11 @@
 # on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
-
-import doctest
 import functools
 import itertools
 import operator
 import textwrap
+from pydoc import locate
 from types import SimpleNamespace
 from typing import (
     Any,
@@ -316,13 +315,7 @@ class NumpyFunc(Lifted):
         func_args: Tuple[Any, ...],
         func_kwargs: Dict[str, Any],
     ):
-        import numpy
-
-        splits = func.split(".")
-        b = numpy
-        for s in splits:
-            b = getattr(b, s)
-        self.func = b
+        self.func: Callable = locate(f"numpy.{func}")  # type: ignore
         self.func_args = func_args
         self.func_kwargs = func_kwargs
 
@@ -645,7 +638,7 @@ class BinaryMarkovChain(Lifted):
         probs = np.zeros(2)
         probs[0] = resolve(self.zero_to_one, x, length, *args, **kwargs)
         probs[1] = resolve(self.one_to_zero, x, length, *args, **kwargs)
-        out = np.ones(length, dtype=np.int)  # initial state is 1
+        out = np.ones(length, dtype=int)  # initial state is 1
         uu = np.random.rand(length)
         for i in range(1, length):
             if uu[i] < probs[out[i - 1]]:
@@ -778,7 +771,7 @@ class ForEachCat(Lifted):
         if field_name not in global_state:
             global_state[field_name] = np.empty(
                 len(global_state[self.cat_field][self.cat_idx]),
-                dtype=np.object,
+                dtype=object,
             )
         if global_state[field_name][c] is None:
             global_state[field_name][c] = self.fun(
@@ -960,12 +953,12 @@ class RandomChangepoints(Lifted):
             self.max_num_changepoints, x, length, *args, **kwargs
         )
         num_changepoints = np.random.randint(0, max_num_changepoints + 1)
-        change_idx = np.sort(
+        change_idx: np.ndarray = np.sort(
             np.random.randint(low=1, high=length - 1, size=(num_changepoints,))
         )
-        change_ranges = np.concatenate([change_idx, [length]])
-        out = np.zeros(length, dtype=np.int)
-        for i in range(0, num_changepoints):
+        change_ranges: np.ndarray = np.concatenate([change_idx, [length]])  # type: ignore
+        out = np.zeros(length, dtype=int)
+        for i in range(num_changepoints):
             out[change_ranges[i] : change_ranges[i + 1]] = i + 1
         return out
 
