@@ -13,10 +13,4 @@
 
 __all__ = ["DateSplitter", "OffsetSplitter"]
 
-# Relative imports
 from .splitter import DateSplitter, OffsetSplitter
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
