@@ -20,8 +20,3 @@ __all__ = [
     "make_evaluation_predictions",
     "backtest_metrics",
 ]
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
