@@ -12,34 +12,35 @@
 # permissions and limitations under the License.
 
 from functools import partial
-from typing import List, Optional, Callable
+from typing import List, Optional, Type
 
 import numpy as np
 from mxnet.gluon import HybridBlock
 
-from gluonts.core.component import DType, validated
+from gluonts.core.component import validated
 from gluonts.dataset.common import Dataset
 from gluonts.dataset.field_names import FieldName
 from gluonts.dataset.loader import (
+    DataLoader,
     TrainDataLoader,
     ValidationDataLoader,
-    DataLoader,
 )
-from gluonts.mx.model.estimator import GluonEstimator
+from gluonts.env import env
 from gluonts.model.predictor import Predictor
-from gluonts.mx.batchify import batchify, as_in_context
+from gluonts.mx.batchify import as_in_context, batchify
 from gluonts.mx.kernels import KernelOutput, RBFKernelOutput
+from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.mx.model.predictor import RepresentableBlockPredictor
 from gluonts.mx.trainer import Trainer
 from gluonts.mx.util import copy_parameters, get_hybrid_forward_input_names
+from gluonts.itertools import maybe_len
 from gluonts.time_feature import TimeFeature, time_features_from_frequency_str
 from gluonts.transform import (
     AddTimeFeatures,
     AsNumpyArray,
     CanonicalInstanceSplitter,
-    Chain,
-    SetFieldIfNotPresent,
     SelectFields,
+    SetFieldIfNotPresent,
     TestSplitSampler,
     Transformation,
 )
@@ -112,7 +113,7 @@ class GaussianProcessEstimator(GluonEstimator):
         context_length: Optional[int] = None,
         kernel_output: KernelOutput = RBFKernelOutput(),
         params_scaling: bool = True,
-        dtype: DType = np.float64,
+        dtype: Type = np.float64,
         max_iter_jitter: int = 10,
         jitter_method: str = "iter",
         sample_noise: bool = True,
@@ -181,7 +182,7 @@ class GaussianProcessEstimator(GluonEstimator):
             instance_sampler=TestSplitSampler(),
             time_series_fields=[FieldName.FEAT_TIME],
             instance_length=self.context_length,
-            use_prediction_features=(mode is not "training"),
+            use_prediction_features=(mode != "training"),
             prediction_length=self.prediction_length,
         )
 
@@ -193,7 +194,8 @@ class GaussianProcessEstimator(GluonEstimator):
         input_names = get_hybrid_forward_input_names(
             GaussianProcessTrainingNetwork
         )
-        instance_splitter = self._create_instance_splitter("training")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("training")
         return TrainDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
@@ -211,7 +213,8 @@ class GaussianProcessEstimator(GluonEstimator):
         input_names = get_hybrid_forward_input_names(
             GaussianProcessTrainingNetwork
         )
-        instance_splitter = self._create_instance_splitter("validation")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("validation")
         return ValidationDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
