@@ -24,18 +24,20 @@ from gluonts.dataset.loader import (
     TrainDataLoader,
     ValidationDataLoader,
 )
+from gluonts.env import env
 from gluonts.model.deepvar._estimator import (
     get_lags_for_frequency,
     time_features_from_frequency_str,
 )
-from gluonts.mx.batchify import batchify, as_in_context
-from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.model.predictor import Predictor
+from gluonts.mx.batchify import as_in_context, batchify
 from gluonts.mx.distribution import DistributionOutput
 from gluonts.mx.distribution.lowrank_gp import LowrankGPOutput
+from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.mx.model.predictor import RepresentableBlockPredictor
 from gluonts.mx.trainer import Trainer
 from gluonts.mx.util import copy_parameters, get_hybrid_forward_input_names
+from gluonts.itertools import maybe_len
 from gluonts.time_feature import TimeFeature
 from gluonts.transform import (
     AddObservedValuesIndicator,
@@ -45,18 +47,18 @@ from gluonts.transform import (
     Chain,
     ExpandDimArray,
     ExpectedNumInstanceSampler,
+    InstanceSampler,
     InstanceSplitter,
     RenameFields,
     SampleTargetDim,
-    SetFieldIfNotPresent,
     SelectFields,
+    SetFieldIfNotPresent,
     TargetDimIndicator,
+    TestSplitSampler,
     Transformation,
+    ValidationSplitSampler,
     VstackFeatures,
     cdf_to_gaussian_forward_transform,
-    InstanceSampler,
-    ValidationSplitSampler,
-    TestSplitSampler,
 )
 
 from ._network import GPVARPredictionNetwork, GPVARTrainingNetwork
@@ -337,7 +339,8 @@ class GPVAREstimator(GluonEstimator):
         **kwargs,
     ) -> DataLoader:
         input_names = get_hybrid_forward_input_names(GPVARTrainingNetwork)
-        instance_splitter = self._create_instance_splitter("training")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("training")
         return TrainDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
@@ -353,7 +356,8 @@ class GPVAREstimator(GluonEstimator):
         **kwargs,
     ) -> DataLoader:
         input_names = get_hybrid_forward_input_names(GPVARTrainingNetwork)
-        instance_splitter = self._create_instance_splitter("validation")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("validation")
         return ValidationDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
@@ -375,7 +379,6 @@ class GPVAREstimator(GluonEstimator):
             lags_seq=self.lags_seq,
             scaling=self.scaling,
             distr_output=self.distr_output,
-            conditioning_length=self.conditioning_length,
         )
 
     def create_predictor(
@@ -397,7 +400,6 @@ class GPVAREstimator(GluonEstimator):
             lags_seq=self.lags_seq,
             scaling=self.scaling,
             distr_output=self.distr_output,
-            conditioning_length=self.conditioning_length,
         )
 
         copy_parameters(trained_network, prediction_network)
