@@ -12,37 +12,38 @@
 # permissions and limitations under the License.
 
 from functools import partial
-from typing import Optional
+from typing import Optional, Type
 
 import numpy as np
 from mxnet.gluon import HybridBlock
 
-from gluonts.core.component import DType, validated
+from gluonts.core.component import validated
 from gluonts.dataset.common import Dataset
+from gluonts.dataset.field_names import FieldName
 from gluonts.dataset.loader import (
     DataLoader,
     TrainDataLoader,
     ValidationDataLoader,
 )
-from gluonts.dataset.field_names import FieldName
-from gluonts.mx.model.estimator import GluonEstimator
+from gluonts.env import env
 from gluonts.model.lstnet._network import LSTNetPredict, LSTNetTrain
 from gluonts.model.predictor import Predictor
-from gluonts.mx.batchify import batchify, as_in_context
+from gluonts.mx.batchify import as_in_context, batchify
+from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.mx.model.predictor import RepresentableBlockPredictor
 from gluonts.mx.trainer import Trainer
 from gluonts.mx.util import copy_parameters, get_hybrid_forward_input_names
+from gluonts.itertools import maybe_len
 from gluonts.transform import (
     AddObservedValuesIndicator,
     AsNumpyArray,
-    Chain,
     ExpectedNumInstanceSampler,
+    InstanceSampler,
     InstanceSplitter,
     SelectFields,
-    Transformation,
-    InstanceSampler,
-    ValidationSplitSampler,
     TestSplitSampler,
+    Transformation,
+    ValidationSplitSampler,
 )
 
 
@@ -136,7 +137,7 @@ class LSTNetEstimator(GluonEstimator):
         train_sampler: Optional[InstanceSampler] = None,
         validation_sampler: Optional[InstanceSampler] = None,
         batch_size: int = 32,
-        dtype: DType = np.float32,
+        dtype: Type = np.float32,
     ) -> None:
         super().__init__(
             trainer=trainer,
@@ -214,7 +215,8 @@ class LSTNetEstimator(GluonEstimator):
         **kwargs,
     ) -> DataLoader:
         input_names = get_hybrid_forward_input_names(LSTNetTrain)
-        instance_splitter = self._create_instance_splitter("training")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("training")
         return TrainDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
@@ -230,7 +232,8 @@ class LSTNetEstimator(GluonEstimator):
         **kwargs,
     ) -> DataLoader:
         input_names = get_hybrid_forward_input_names(LSTNetTrain)
-        instance_splitter = self._create_instance_splitter("validation")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("validation")
         return ValidationDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
