@@ -12,7 +12,7 @@
 # permissions and limitations under the License.
 
 from functools import partial
-from typing import List, Optional, Callable
+from typing import List, Optional
 
 from mxnet.gluon import HybridBlock
 
@@ -24,22 +24,23 @@ from gluonts.dataset.loader import (
     TrainDataLoader,
     ValidationDataLoader,
 )
-from gluonts.mx.batchify import batchify, as_in_context
-from gluonts.mx.model.estimator import GluonEstimator
+from gluonts.env import env
 from gluonts.model.predictor import Predictor
+from gluonts.mx.batchify import as_in_context, batchify
+from gluonts.mx.model.estimator import GluonEstimator
 from gluonts.mx.model.predictor import RepresentableBlockPredictor
 from gluonts.mx.trainer import Trainer
 from gluonts.mx.util import get_hybrid_forward_input_names
+from gluonts.itertools import maybe_len
 from gluonts.transform import (
-    Chain,
-    ExpectedNumInstanceSampler,
-    InstanceSplitter,
-    Transformation,
-    InstanceSampler,
-    ValidationSplitSampler,
-    TestSplitSampler,
     AddObservedValuesIndicator,
+    ExpectedNumInstanceSampler,
+    InstanceSampler,
+    InstanceSplitter,
     SelectFields,
+    TestSplitSampler,
+    Transformation,
+    ValidationSplitSampler,
 )
 
 from ._network import (
@@ -292,7 +293,8 @@ class NBEATSEstimator(GluonEstimator):
         **kwargs,
     ) -> DataLoader:
         input_names = get_hybrid_forward_input_names(NBEATSTrainingNetwork)
-        instance_splitter = self._create_instance_splitter("training")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("training")
         return TrainDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
@@ -308,7 +310,8 @@ class NBEATSEstimator(GluonEstimator):
         **kwargs,
     ) -> DataLoader:
         input_names = get_hybrid_forward_input_names(NBEATSTrainingNetwork)
-        instance_splitter = self._create_instance_splitter("validation")
+        with env._let(max_idle_transforms=maybe_len(data) or 0):
+            instance_splitter = self._create_instance_splitter("validation")
         return ValidationDataLoader(
             dataset=data,
             transform=instance_splitter + SelectFields(input_names),
