@@ -11,16 +11,14 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
-from typing import List
+from typing import List, Optional
 
-# Third-party imports
 import mxnet as mx
 import numpy as np
 
-# First-party imports
 from gluonts.core.component import validated
-from gluonts.model.common import Tensor
+from gluonts.mx import Tensor
+from gluonts.mx.block.scaler import MeanScaler, NOPScaler
 from gluonts.time_feature import get_seasonality
 
 VALID_N_BEATS_STACK_TYPES = "G", "S", "T"
@@ -75,7 +73,7 @@ def trend_model(
     t = linear_space(
         F, context_length, prediction_length, fwd_looking=is_forecast
     )
-    T = F.stack(*[t ** i for i in range(num_coefficients)])
+    T = F.stack(*[t**i for i in range(num_coefficients)])
     return T
 
 
@@ -209,19 +207,19 @@ class NBEATSGenericBlock(NBEATSBlock):
             if self.has_backcast:
                 self.theta_backcast = mx.gluon.nn.Dense(
                     units=self.expansion_coefficient_length,
-                    prefix=f"theta_backcast_dense_",  # linear activation:
+                    prefix="theta_backcast_dense_",  # linear activation:
                 )
                 self.backcast = mx.gluon.nn.Dense(
                     units=self.context_length,
-                    prefix=f"backcast_dense_",  # linear activation:
+                    prefix="backcast_dense_",  # linear activation:
                 )
             self.theta_forecast = mx.gluon.nn.Dense(
                 units=self.expansion_coefficient_length,
-                prefix=f"theta_forecast_dense_",  # linear activation:
+                prefix="theta_forecast_dense_",  # linear activation:
             )
             self.forecast = mx.gluon.nn.Dense(
                 units=self.prediction_length,
-                prefix=f"theta_dense_",  # linear activation:
+                prefix="theta_dense_",  # linear activation:
             )
 
 
@@ -264,19 +262,19 @@ class NBEATSSeasonalBlock(NBEATSBlock):
             if self.has_backcast:
                 self.theta_backcast = mx.gluon.nn.Dense(
                     units=2 * self.num_coefficients,
-                    prefix=f"theta_backcast_dense_",  # linear activation:
+                    prefix="theta_backcast_dense_",  # linear activation:
                 )
                 self.backcast = mx.gluon.nn.HybridLambda(
                     lambda F, thetas: F.dot(thetas, self.backcast_basis),
-                    prefix=f"backcast_lambda_",
+                    prefix="backcast_lambda_",
                 )
             self.theta_forecast = mx.gluon.nn.Dense(
                 units=2 * self.num_coefficients,
-                prefix=f"theta_forecast_dense_",  # linear activation:
+                prefix="theta_forecast_dense_",  # linear activation:
             )
             self.forecast = mx.gluon.nn.HybridLambda(
                 lambda F, thetas: F.dot(thetas, self.forecast_basis),
-                prefix=f"forecast_lambda_",
+                prefix="forecast_lambda_",
             )
 
     def initialize_basis(self, F):
@@ -300,7 +298,7 @@ class NBEATSSeasonalBlock(NBEATSBlock):
 
 
 class NBEATSTrendBlock(NBEATSBlock):
-    """"
+    """ "
     The NBEATS Block as described in the paper: https://arxiv.org/abs/1905.10437.
     This is the Trend block variant.
 
@@ -335,19 +333,19 @@ class NBEATSTrendBlock(NBEATSBlock):
             if self.has_backcast:
                 self.theta_backcast = mx.gluon.nn.Dense(
                     units=self.expansion_coefficient_length,
-                    prefix=f"theta_backcast_dense_",  # linear activation:
+                    prefix="theta_backcast_dense_",  # linear activation:
                 )
                 self.backcast = mx.gluon.nn.HybridLambda(
                     lambda F, thetas: F.dot(thetas, self.backcast_basis),
-                    prefix=f"backcast_lambda_",
+                    prefix="backcast_lambda_",
                 )
             self.theta_forecast = mx.gluon.nn.Dense(
                 units=self.expansion_coefficient_length,
-                prefix=f"theta_forecast_dense_",  # linear activation:
+                prefix="theta_forecast_dense_",  # linear activation:
             )
             self.forecast = mx.gluon.nn.HybridLambda(
                 lambda F, thetas: F.dot(thetas, self.forecast_basis),
-                prefix=f"forecast_lambda_",
+                prefix="forecast_lambda_",
             )
 
     def initialize_basis(self, F):
@@ -419,6 +417,8 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         A list of strings of length 1 or 'num_stacks'.
         Default and recommended value for generic mode: ["G"]
         Recommended value for interpretable mode: ["T","S"]
+    scale
+        if True scales the input observations by the mean
     kwargs
         Arguments passed to 'HybridBlock'.
     """
@@ -437,6 +437,7 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         expansion_coefficient_lengths: List[int],
         sharing: List[bool],
         stack_types: List[str],
+        scale: bool = False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -451,6 +452,11 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         self.prediction_length = prediction_length
         self.context_length = context_length
 
+        if scale:
+            self.scaler = MeanScaler(keepdims=True)
+        else:
+            self.scaler = NOPScaler(keepdims=True)
+
         with self.name_scope():
             self.net_blocks: List[NBEATSBlock] = []
 
@@ -511,21 +517,39 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
                     )
 
     # noinspection PyMethodOverriding,PyPep8Naming
-    def hybrid_forward(self, F, past_target: Tensor, future_target: Tensor):
+    def hybrid_forward(
+        self,
+        F,
+        past_target: Tensor,
+        past_observed_values: Tensor,
+        future_target: Optional[Tensor],
+        future_observed_values: Optional[Tensor],
+    ):
+
+        past_target, scale = self.scaler(past_target, past_observed_values)
+
         if len(self.net_blocks) == 1:  # if first block is also last block
-            return self.net_blocks[0](past_target)
+            forecast = self.net_blocks[0](past_target)
         else:
             backcast, forecast = self.net_blocks[0](past_target)
-            backcast = past_target - backcast
+            backcast = (past_target - backcast) * past_observed_values
             # connect regular blocks (all except last)
             for i in range(1, len(self.net_blocks) - 1):
                 b, f = self.net_blocks[i](backcast)
-                backcast = backcast - b
+                backcast = (backcast - b) * past_observed_values
                 forecast = forecast + f
             # connect last block
-            return forecast + self.net_blocks[-1](backcast)
+            forecast = forecast + self.net_blocks[-1](backcast)
 
-    def smape_loss(self, F, forecast: Tensor, future_target: Tensor) -> Tensor:
+        return F.broadcast_mul(forecast, scale)
+
+    def smape_loss(
+        self,
+        F,
+        forecast: Tensor,
+        future_target: Tensor,
+        future_observed_values: Tensor,
+    ) -> Tensor:
         r"""
         .. math::
 
@@ -538,15 +562,24 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         denominator = F.stop_gradient(F.abs(future_target) + F.abs(forecast))
         flag = denominator == 0
 
+        absolute_error = (
+            F.abs(future_target - forecast) * future_observed_values
+        )
+
         smape = (200 / self.prediction_length) * F.mean(
-            (F.abs(future_target - forecast) * (1 - flag))
-            / (denominator + flag),
+            (absolute_error * (1 - flag)) / (denominator + flag),
             axis=1,
         )
 
         return smape
 
-    def mape_loss(self, F, forecast: Tensor, future_target: Tensor) -> Tensor:
+    def mape_loss(
+        self,
+        F,
+        forecast: Tensor,
+        future_target: Tensor,
+        future_observed_values: Tensor,
+    ) -> Tensor:
         r"""
         .. math::
 
@@ -558,9 +591,12 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         denominator = F.abs(future_target)
         flag = denominator == 0
 
+        absolute_error = (
+            F.abs(future_target - forecast) * future_observed_values
+        )
+
         mape = (100 / self.prediction_length) * F.mean(
-            (F.abs(future_target - forecast) * (1 - flag))
-            / (denominator + flag),
+            (absolute_error * (1 - flag)) / (denominator + flag),
             axis=1,
         )
 
@@ -573,6 +609,7 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         future_target: Tensor,
         past_target: Tensor,
         periodicity: int,
+        future_observed_values: Tensor,
     ) -> Tensor:
         r"""
         .. math::
@@ -591,9 +628,13 @@ class NBEATSNetwork(mx.gluon.HybridBlock):
         )
         flag = seasonal_error == 0
 
-        mase = (
-            F.mean(F.abs(future_target - forecast), axis=1) * (1 - flag)
-        ) / (seasonal_error + flag)
+        absolute_error = (
+            F.abs(future_target - forecast) * future_observed_values
+        )
+
+        mase = (F.mean(absolute_error, axis=1) * (1 - flag)) / (
+            seasonal_error + flag
+        )
 
         return mase
 
@@ -619,7 +660,12 @@ class NBEATSTrainingNetwork(NBEATSNetwork):
 
     # noinspection PyMethodOverriding,PyPep8Naming
     def hybrid_forward(
-        self, F, past_target: Tensor, future_target: Tensor
+        self,
+        F,
+        past_target: Tensor,
+        past_observed_values: Tensor,
+        future_target: Tensor,
+        future_observed_values: Tensor,
     ) -> Tensor:
         """
 
@@ -629,27 +675,45 @@ class NBEATSTrainingNetwork(NBEATSNetwork):
         past_target
             Tensor with past observations.
             Shape: (batch_size, context_length, target_dim).
+        past_observed_values
+            Tensor with past observed values.
+            Shape: (batch_size, context_length, target_dim).
         future_target
             Tensor with future observations.
             Shape: (batch_size, prediction_length, target_dim).
+        future_observed_values
+            Tensor with future observed values.
+            Shape: (batch_size, prediction_length, target_dim).
 
         Returns
         -------
         Tensor
             Loss tensor. Shape: (batch_size, ).
         """
-        # future_target never used
         forecast = super().hybrid_forward(
-            F, past_target=past_target, future_target=future_target
+            F,
+            past_target=past_target,
+            past_observed_values=past_observed_values,
+            future_target=None,
+            future_observed_values=None,
         )
 
         if self.loss_function == "sMAPE":
-            loss = self.smape_loss(F, forecast, future_target)
+            loss = self.smape_loss(
+                F, forecast, future_target, future_observed_values
+            )
         elif self.loss_function == "MAPE":
-            loss = self.mape_loss(F, forecast, future_target)
+            loss = self.mape_loss(
+                F, forecast, future_target, future_observed_values
+            )
         elif self.loss_function == "MASE":
             loss = self.mase_loss(
-                F, forecast, future_target, past_target, self.periodicity
+                F,
+                forecast,
+                future_target,
+                past_target,
+                self.periodicity,
+                future_observed_values,
             )
         else:
             raise ValueError(
@@ -666,7 +730,12 @@ class NBEATSPredictionNetwork(NBEATSNetwork):
 
     # noinspection PyMethodOverriding,PyPep8Naming
     def hybrid_forward(
-        self, F, past_target: Tensor, future_target: Tensor = None
+        self,
+        F,
+        past_target: Tensor,
+        past_observed_values: Tensor,
+        future_target: Optional[Tensor] = None,
+        future_observed_values: Optional[Tensor] = None,
     ) -> Tensor:
         """
 
@@ -676,17 +745,25 @@ class NBEATSPredictionNetwork(NBEATSNetwork):
         past_target
             Tensor with past observations.
             Shape: (batch_size, context_length, target_dim).
+        past_observed_values
+            Tensor with past observed values.
+            Shape: (batch_size, context_length, target_dim).
         future_target
             Not used.
+        future_observed_values
+            Not used.
 
         Returns
         -------
         Tensor
             Prediction sample. Shape: (batch_size, 1, prediction_length).
         """
-        # future_target never used
         forecasts = super().hybrid_forward(
-            F, past_target=past_target, future_target=past_target
+            F,
+            past_target=past_target,
+            past_observed_values=past_observed_values,
+            future_target=None,
+            future_observed_values=None,
         )
 
         # dimension collapsed previously because we only have one sample each:
