@@ -11,21 +11,16 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
 from typing import Optional
 
-# Third-party imports
 import numpy as np
-
-# Third-party imports
 import statsmodels.api as sm
 
-# First-party imports
 from gluonts.core.component import validated
 from gluonts.dataset.common import DataEntry
+from gluonts.dataset.util import forecast_start
 from gluonts.model.forecast import Forecast, SampleForecast
 from gluonts.model.predictor import RepresentablePredictor
-from gluonts.support.pandas import forecast_start
 from gluonts.time_feature import get_seasonality
 
 
