@@ -28,9 +28,9 @@ import numpy as np
 import gluonts
 from gluonts.core import fqname_for
 from gluonts.core.component import equals, from_hyperparameters, validated
-from gluonts.core.exception import GluonTSException
 from gluonts.core.serde import dump_json, load_json
 from gluonts.dataset.common import DataEntry, Dataset
+from gluonts.exceptions import GluonTSException
 from gluonts.model.forecast import Forecast
 
 if TYPE_CHECKING:  # avoid circular import
@@ -106,7 +106,10 @@ class Predictor:
         """
         # deserialize Predictor type
         with (path / "type.txt").open("r") as fp:
-            tpe = locate(fp.readline())
+            tpe_str = fp.readline()
+
+        tpe = locate(tpe_str)
+        assert tpe is not None, f"Cannot locate {tpe_str}."
 
         # ensure that predictor_cls is a subtype of Predictor
         if not issubclass(tpe, Predictor):
