@@ -11,12 +11,6 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Relative imports
 from ._predictor import PROPHET_IS_INSTALLED, ProphetPredictor
 
 __all__ = ["ProphetPredictor", "PROPHET_IS_INSTALLED"]
-
-# fix Sphinx issues, see https://bit.ly/2K2eptM
-for item in __all__:
-    if hasattr(item, "__module__"):
-        setattr(item, "__module__", __name__)
