@@ -71,7 +71,7 @@ class QRX:
         self,
         model=None,
         xgboost_params: Optional[dict] = None,
-        clump_size: int = 100,
+        min_bin_size: int = 100,
     ):
         """
         QRX is an algorithm that takes a point estimate algorithm and turns it
@@ -83,7 +83,7 @@ class QRX:
         Prediction is done by taking empirical quantiles of *true values*
         associated with point estimate predictions close to the point
         estimate of the given point. The minimal number of associated true
-        values is determined by clump_size.
+        values is determined by min_bin_size.
 
         The algorithm is (loosely) inspired by quantile regression
         forests, in that it is predicts quantiles based on associated true
@@ -97,7 +97,7 @@ class QRX:
             If None, then it uses
             {"max_depth": 5, "n_jobs": -1, "verbosity": 1,
              "objective": "reg:squarederror"}
-        clump_size
+        min_bin_size
             Hyperparameter that determines the minimal size of the list of
             true values associated with each prediction.
         """
@@ -105,7 +105,7 @@ class QRX:
             self.model = copy.deepcopy(model)
         else:
             self.model = self._create_xgboost_model(xgboost_params)
-        self.clump_size = clump_size
+        self.min_bin_size = min_bin_size
         self.sorted_train_preds = None
         self.x_train_is_dataframe = None
         self.id_to_bins = None
@@ -138,6 +138,8 @@ class QRX:
         seed: int = 1,
         x_train_is_dataframe: bool = False,  # This should be False for
         # XGBoost, but True if one uses lightgbm.
+        model_is_already_trained: bool = False,  # True if there is no need to
+        # train self.model
         **kwargs
     ):
         """
@@ -170,7 +172,8 @@ class QRX:
             )
             x_train = x_train[idx]
             y_train = y_train[idx]
-        self.model.fit(x_train, y_train, **kwargs)
+        if not model_is_already_trained:
+            self.model.fit(x_train, y_train, **kwargs)
         y_train_pred = self.model.predict(x_train)
         df = pd.DataFrame(
             {
@@ -179,7 +182,9 @@ class QRX:
             }
         ).reset_index(drop=True)
         self.sorted_train_preds = sorted(df["y_pred"].unique())
-        cell_values_dict = self.preprocess_df(df, clump_size=self.clump_size)
+        cell_values_dict = self.preprocess_df(
+            df, min_bin_size=self.min_bin_size
+        )
         del df
         gc.collect()
         cell_values_dict_df = pd.DataFrame(
@@ -196,6 +201,14 @@ class QRX:
         del cell_values_dict
         gc.collect()
 
+        df = pd.DataFrame({"preds": self.sorted_train_preds})
+        df["bin_ids"] = df["preds"].apply(lambda x: self.preds_to_id[x])
+        bin_ids = df["bin_ids"].drop_duplicates().values
+        if len(bin_ids) > 1:
+            final_id, penultimate_id = bin_ids[-1], bin_ids[-2]
+            if len(self.id_to_bins[final_id]) < self.min_bin_size:
+                self.id_to_bins[final_id] += self.id_to_bins[penultimate_id]
+
     @staticmethod
     def clump(
         dic: Dict, min_num: int, sorted_keys: Optional[List] = None
@@ -248,14 +261,14 @@ class QRX:
             new_dic[key] = iter_list  # Note that iter_list may change in the
             # future, and this will change the value of new_dic[key]. This
             # is intentional.
-            if iter_length > min_num:
+            if iter_length >= min_num:
                 iter_length = 0
                 iter_list = []  # This line, of course, doesn't change any
                 # value of new_dic, as it makes iter_list reference a new
                 # list object.
         return new_dic
 
-    def preprocess_df(self, df: pd.DataFrame, clump_size: int = 100) -> Dict:
+    def preprocess_df(self, df: pd.DataFrame, min_bin_size: int = 100) -> Dict:
         """
         Associates true values to each prediction that appears in train. For
         the nature of this association, see details in .clump.
@@ -265,7 +278,7 @@ class QRX:
         df: pd.DataFrame
             Dataframe with columns 'y_true' and 'y_pred', of true and
             predicted values on the training set.
-        clump_size
+        min_bin_size
             Size of clumps to associate to each prediction in the set of
             predictions on the training set.
 
@@ -274,10 +287,10 @@ class QRX:
         dict
             going from predictions from the set of predictions on the
             training set to lists of associated true values, with the length
-            of each being at least clump_size.
+            of each being at least min_bin_size.
         """
         dic = dict(df.groupby("y_pred")["y_true"].apply(list))
-        dic = self.clump(dic, clump_size, self.sorted_train_preds)
+        dic = self.clump(dic, min_bin_size, self.sorted_train_preds)
         return dic
 
     @classmethod
@@ -391,3 +404,8 @@ class QRX:
                 self.id_to_bins[self.preds_to_id[closest_pred]]
             )
         return predicted_samples
+
+
+LSF = QRX  # LSF stands for "Level Set Forecaster". This name emphasizes that
+# the underlying algorithm can be used with any point forecasting algorithm,
+# not just XGBoost.
