@@ -11,27 +11,22 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
-from typing import List, Optional, Tuple
+from typing import List, Type
 
-# Third-party imports
 import numpy as np
-import mxnet as nx
-from mxnet import gluon
-from mxnet import init
-from mxnet.gluon import nn, HybridBlock
+from mxnet.gluon import HybridBlock, nn
 
-# First-party imports
-from gluonts.core.component import validated, DType
-from gluonts.model.common import Tensor
+from gluonts.core.component import validated
+from gluonts.mx import Tensor
 from gluonts.mx.block.feature import FeatureEmbedder as BaseFeatureEmbedder
 from gluonts.mx.block.quantile_output import QuantileOutput
-from gluonts.support.util import weighted_average
+from gluonts.mx.util import weighted_average
+
 from ._layers import (
     GatedResidualNetwork,
-    VariableSelectionNetwork,
-    TemporalFusionEncoder,
     TemporalFusionDecoder,
+    TemporalFusionEncoder,
+    VariableSelectionNetwork,
 )
 
 
@@ -70,7 +65,7 @@ class FeatureProjector(HybridBlock):
         self,
         feature_dims: List[int],
         embedding_dims: List[int],
-        dtype: DType = np.float32,
+        dtype: Type = np.float32,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -132,7 +127,9 @@ class FeatureProjector(HybridBlock):
         if self.__num_features > 1:
             # we slice the last dimension, giving an array of length self.__num_features with shape (N,T) or (N)
             real_feature_slices = F.split_v2(
-                features, tuple(np.cumsum(self.feature_dims)[:-1]), axis=-1,
+                features,
+                tuple(np.cumsum(self.feature_dims)[:-1]),
+                axis=-1,
             )
         else:
             # F.split will iterate over the second-to-last axis if the last axis is one
@@ -199,7 +196,7 @@ class TemporalFusionTransformerNetwork(HybridBlock):
                 units=self.d_var,
                 in_units=1,
                 flatten=False,
-                prefix=f"target_projection_",
+                prefix="target_projection_",
             )
             if self.d_past_feat_dynamic_real:
                 self.past_feat_dynamic_proj = FeatureProjector(
@@ -276,16 +273,22 @@ class TemporalFusionTransformerNetwork(HybridBlock):
                 dropout=dropout,
             )
             self.selection = GatedResidualNetwork(
-                d_hidden=self.d_var, dropout=dropout,
+                d_hidden=self.d_var,
+                dropout=dropout,
             )
             self.enrichment = GatedResidualNetwork(
-                d_hidden=self.d_var, dropout=dropout,
+                d_hidden=self.d_var,
+                dropout=dropout,
             )
             self.state_h = GatedResidualNetwork(
-                d_hidden=self.d_var, d_output=self.d_hidden, dropout=dropout,
+                d_hidden=self.d_var,
+                d_output=self.d_hidden,
+                dropout=dropout,
             )
             self.state_c = GatedResidualNetwork(
-                d_hidden=self.d_var, d_output=self.d_hidden, dropout=dropout,
+                d_hidden=self.d_var,
+                d_output=self.d_hidden,
+                dropout=dropout,
             )
             self.temporal_encoder = TemporalFusionEncoder(
                 context_length=self.context_length,
@@ -320,21 +323,24 @@ class TemporalFusionTransformerNetwork(HybridBlock):
         obs = F.broadcast_mul(past_target, past_observed_values)
         count = F.sum(past_observed_values, axis=1, keepdims=True)
         offset = F.broadcast_div(
-            F.sum(obs, axis=1, keepdims=True), count + self.normalize_eps,
+            F.sum(obs, axis=1, keepdims=True),
+            count + self.normalize_eps,
         )
         scale = F.broadcast_div(
-            F.sum(obs ** 2, axis=1, keepdims=True), count + self.normalize_eps,
+            F.sum(obs**2, axis=1, keepdims=True),
+            count + self.normalize_eps,
         )
-        scale = F.broadcast_sub(scale, offset ** 2)
+        scale = F.broadcast_sub(scale, offset**2)
         scale = F.sqrt(scale)
         past_target = F.broadcast_div(
-            F.broadcast_sub(past_target, offset), scale + self.normalize_eps,
+            F.broadcast_sub(past_target, offset),
+            scale + self.normalize_eps,
         )
         past_target = F.expand_dims(past_target, axis=-1)
 
         past_covariates = []
         future_covariates = []
-        static_covariates = []
+        static_covariates: List[Tensor] = []
         proj = self.target_proj(past_target)
         past_covariates.append(proj)
         if self.past_feat_dynamic_proj is not None:
@@ -382,12 +388,17 @@ class TemporalFusionTransformerNetwork(HybridBlock):
         )
 
     def _postprocess(
-        self, F, preds: Tensor, offset: Tensor, scale: Tensor,
+        self,
+        F,
+        preds: Tensor,
+        offset: Tensor,
+        scale: Tensor,
     ) -> Tensor:
         offset = F.expand_dims(offset, axis=-1)
         scale = F.expand_dims(scale, axis=-1)
         preds = F.broadcast_add(
-            F.broadcast_mul(preds, (scale + self.normalize_eps)), offset,
+            F.broadcast_mul(preds, (scale + self.normalize_eps)),
+            offset,
         )
         return preds
 
