@@ -11,17 +11,13 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
 from typing import List, Optional, Tuple
 
-# Third-party imports
-from mxnet import nd
 from mxnet.gluon import nn
 from mxnet.gluon.loss import Loss
 
-# First-party imports
 from gluonts.core.component import validated
-from gluonts.model.common import Tensor
+from gluonts.mx import Tensor
 
 
 class QuantileLoss(Loss):
@@ -29,9 +25,10 @@ class QuantileLoss(Loss):
     def __init__(
         self,
         quantiles: List[float],
-        quantile_weights: List[float] = None,
-        weight=None,
-        batch_axis=0,
+        quantile_weights: Optional[List[float]] = None,
+        is_equal_weights: bool = True,
+        weight: Optional[float] = None,
+        batch_axis: int = 0,
         **kwargs,
     ) -> None:
         """
@@ -45,20 +42,25 @@ class QuantileLoss(Loss):
         quantile_weights
             weights of the quantiles.
 
-        weight:
+        is_equal_weights
+            use equally quantiles weights or not
+
+        weight
             weighting of the loss.
 
-        batch_axis:
+        batch_axis
             indicates axis that represents the batch.
         """
         super().__init__(weight, batch_axis, **kwargs)
 
         self.quantiles = quantiles
         self.num_quantiles = len(quantiles)
+        self.is_equal_weights = is_equal_weights
+
         self.quantile_weights = (
-            [1.0 / self.num_quantiles for i in range(self.num_quantiles)]
-            if not quantile_weights
-            else quantile_weights
+            quantile_weights
+            if quantile_weights
+            else self.compute_quantile_weights()
         )
 
     # noinspection PyMethodOverriding
@@ -146,6 +148,39 @@ class QuantileLoss(Loss):
 
         return qt_loss
 
+    def compute_quantile_weights(self) -> List:
+        """
+        Compute the exact weights of the approximated integral
+        CRPS = sum_{i=0}^{n-1} 0.5 * (q_{i+1} - q_{i}) * (z_{i+1} + z_{i})
+        under the assumption of linear interpolation or SQF, where z_i is the
+        ith quantile prediction q_i. The inner terms cancel due to the telescoping sum
+        property and we obtain CRPS = sum_{i=1}^n w_i z_i, with the weights
+        w_i = (q_{i+1}-q_{i-1})/2 for i = 1, ..., n-1,
+        w_0 = (q_1-q_0)/2 and w_n = (w_n - w_{n-1})/2.
+
+        Returns
+        -------
+        List
+            weights of the quantiles.
+        """
+        assert (
+            self.num_quantiles >= 0
+        ), f"invalid num_quantiles: {self.num_quantiles}"
+        if self.num_quantiles == 0:  # edge case
+            quantile_weights = []
+        elif self.is_equal_weights or self.num_quantiles == 1:
+            quantile_weights = [1.0 / self.num_quantiles] * self.num_quantiles
+        else:
+            quantile_weights = (
+                [0.5 * (self.quantiles[1] - self.quantiles[0])]
+                + [
+                    0.5 * (self.quantiles[i + 1] - self.quantiles[i - 1])
+                    for i in range(1, self.num_quantiles - 1)
+                ]
+                + [0.5 * (self.quantiles[-1] - self.quantiles[-2])]
+            )
+        return quantile_weights
+
 
 class ProjectParams(nn.HybridBlock):
     """
@@ -156,14 +191,29 @@ class ProjectParams(nn.HybridBlock):
     ----------
     num_quantiles
         number of quantiles to compute the projection.
+    is_iqf
+        determines whether to use IQF or QF.
     """
 
     @validated()
-    def __init__(self, num_quantiles, **kwargs):
+    def __init__(self, num_quantiles: int, is_iqf: bool = False, **kwargs):
         super().__init__(**kwargs)
 
+        self.num_quantiles = num_quantiles
+        self.is_iqf = is_iqf
         with self.name_scope():
-            self.projection = nn.Dense(units=num_quantiles, flatten=False)
+            if self.is_iqf:
+                self.proj_intrcpt = nn.Dense(1, flatten=False)
+                if self.num_quantiles > 1:
+                    self.proj_incrmnt = nn.Dense(
+                        self.num_quantiles - 1,
+                        flatten=False,
+                        activation="relu",
+                    )  # increments between quantile estimates
+            else:
+                self.projection = nn.Dense(
+                    units=self.num_quantiles, flatten=False
+                )
 
     # noinspection PyMethodOverriding,PyPep8Naming
     def hybrid_forward(self, F, x: Tensor) -> Tuple[Tensor, Tensor, Tensor]:
@@ -182,7 +232,22 @@ class ProjectParams(nn.HybridBlock):
         Tensor
             output of the projection layer
         """
-        return self.projection(x)
+        return (
+            (
+                self.proj_intrcpt(x)
+                if self.num_quantiles == 1
+                else (
+                    F.cumsum(
+                        F.concat(
+                            self.proj_intrcpt(x), self.proj_incrmnt(x), dim=-1
+                        ),
+                        axis=3,
+                    )
+                )
+            )
+            if self.is_iqf
+            else self.projection(x)
+        )
 
 
 class QuantileOutput:
@@ -192,11 +257,14 @@ class QuantileOutput:
 
     Parameters
     ----------
-        quantiles
-            list of quantiles to compute loss over.
+    quantiles
+        list of quantiles to compute loss over.
 
-        quantile_weights
-            weights of the quantiles.
+    quantile_weights
+        weights of the quantiles.
+
+    is_iqf
+        determines whether to use IQF or QF.
     """
 
     @validated()
@@ -204,9 +272,13 @@ class QuantileOutput:
         self,
         quantiles: List[float],
         quantile_weights: Optional[List[float]] = None,
+        is_iqf: bool = False,
     ) -> None:
-        self.quantiles = quantiles
+        self.quantiles = sorted(quantiles)
+        self.num_quantiles = len(self.quantiles)
         self.quantile_weights = quantile_weights
+        self.is_iqf = is_iqf
+        self.is_equal_weights = False if self.is_iqf else True
 
     def get_loss(self) -> nn.HybridBlock:
         """
@@ -216,7 +288,9 @@ class QuantileOutput:
             constructs quantile loss object.
         """
         return QuantileLoss(
-            quantiles=self.quantiles, quantile_weights=self.quantile_weights
+            quantiles=self.quantiles,
+            quantile_weights=self.quantile_weights,
+            is_equal_weights=self.is_equal_weights,
         )
 
     def get_quantile_proj(self, **kwargs) -> nn.HybridBlock:
@@ -227,4 +301,4 @@ class QuantileOutput:
             constructs projection parameter object.
 
         """
-        return ProjectParams(len(self.quantiles), **kwargs)
+        return ProjectParams(self.num_quantiles, self.is_iqf, **kwargs)
