@@ -11,22 +11,16 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
 from typing import Dict, Tuple
 
-# Third-party imports
-import numpy as np
 from gluonts.core.component import validated
+from gluonts.mx import Tensor
 
-# First-party imports
-from gluonts.model.common import Tensor
-
-# Relative imports
+from .beta import Beta
+from .deterministic import Deterministic
 from .distribution import getF, softplus
 from .distribution_output import DistributionOutput
-from .beta import Beta
 from .mixture import MixtureDistribution
-from .deterministic import Deterministic
 
 
 class ZeroAndOneInflatedBeta(MixtureDistribution):
@@ -183,10 +177,8 @@ class ZeroAndOneInflatedBetaOutput(DistributionOutput):
             Four squeezed tensors, of shape `(*batch_shape)`: First two have entries mapped to the
             positive orthant, zero_probability is mapped to (0, 1), one_probability is mapped to (0, 1-zero_probability)
         """
-        epsilon = np.finfo(cls._dtype).eps  # machine epsilon
-
-        alpha = softplus(F, alpha) + epsilon
-        beta = softplus(F, beta) + epsilon
+        alpha = F.maximum(softplus(F, alpha), cls.eps())
+        beta = F.maximum(softplus(F, beta), cls.eps())
         zero_probability = F.sigmoid(zero_probability)
         one_probability = (1 - zero_probability) * F.sigmoid(one_probability)
         return (
@@ -231,10 +223,8 @@ class ZeroInflatedBetaOutput(ZeroAndOneInflatedBetaOutput):
             Three squeezed tensors, of shape `(*batch_shape)`: First two have entries mapped to the
             positive orthant, last is mapped to (0,1)
         """
-        epsilon = np.finfo(cls._dtype).eps  # machine epsilon
-
-        alpha = softplus(F, alpha) + epsilon
-        beta = softplus(F, beta) + epsilon
+        alpha = F.maximum(softplus(F, alpha), cls.eps())
+        beta = F.maximum(softplus(F, beta), cls.eps())
         zero_probability = F.sigmoid(zero_probability)
         return (
             alpha.squeeze(axis=-1),
