@@ -90,7 +90,7 @@ class PoissonOutput(DistributionOutput):
 
     @classmethod
     def domain_map(cls, F, rate):
-        rate = softplus(F, rate) + 1e-8
+        rate = F.maximum(softplus(F, rate), cls.eps())
         return rate.squeeze(axis=-1)
 
     # Overwrites the parent class method.
