@@ -23,10 +23,9 @@ from gluonts.dataset.common import Dataset
 from gluonts.evaluation import Evaluator, backtest
 from gluonts.model.estimator import Estimator
 from gluonts.model.forecast import Quantile
-from gluonts.model.forecast_generator import QuantileForecastGenerator
 from gluonts.model.predictor import Predictor
-from gluonts.support.util import maybe_len
-from gluonts.transform import FilterTransformation, TransformedDataset
+from gluonts.itertools import maybe_len
+from gluonts.transform import FilterTransformation
 
 from .env import TrainEnv
 from .util import invoke_with
@@ -120,12 +119,9 @@ def run_test(
 ) -> None:
     len_original = maybe_len(test_dataset)
 
-    test_dataset = TransformedDataset(
-        test_dataset,
-        FilterTransformation(
-            lambda x: x["target"].shape[-1] > predictor.prediction_length
-        ),
-    )
+    test_dataset = FilterTransformation(
+        lambda x: x["target"].shape[-1] > predictor.prediction_length
+    ).apply(test_dataset)
 
     len_filtered = len(test_dataset)
 
@@ -150,18 +146,6 @@ def run_test(
         else None
     )
 
-    forecast_generator = getattr(predictor, "forecast_generator", None)
-    if isinstance(forecast_generator, QuantileForecastGenerator):
-        predictor_quantiles = forecast_generator.quantiles
-        if test_quantiles is None:
-            test_quantiles = predictor_quantiles
-        elif not set(test_quantiles).issubset(predictor_quantiles):
-            logger.warning(
-                f"Some of the evaluation quantiles `{test_quantiles}` are "
-                f"not in the computed quantile forecasts `{predictor_quantiles}`."
-            )
-            test_quantiles = predictor_quantiles
-
     if test_quantiles is not None:
         logger.info(f"Using quantiles `{test_quantiles}` for evaluation.")
         evaluator = Evaluator(quantiles=test_quantiles)
