@@ -11,6 +11,8 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
+# type: ignore
+
 import json
 import multiprocessing
 import socket
@@ -108,7 +110,7 @@ def free_port() -> int:
         return sock.getsockname()[1]
 
 
-@contextmanager  # type: ignore
+@contextmanager
 def temporary_server(
     env: ServeEnv,
     forecaster_type: Optional[Type[Predictor]],
@@ -166,9 +168,10 @@ def temporary_server(
     process.join()
 
 
-@contextmanager  # type: ignore
+@contextmanager
 def temporary_train_env(
-    hyperparameters: Dict[str, Any], dataset_name: str
+    hyperparameters: Dict[str, Any],
+    dataset_name: str,
 ) -> ContextManager[TrainEnv]:
     """
     A context manager that instantiates a training environment from a given
@@ -214,7 +217,7 @@ def temporary_train_env(
         yield TrainEnv(path=paths.base)
 
 
-@contextmanager  # type: ignore
+@contextmanager
 def temporary_serve_env(predictor: Predictor) -> ContextManager[ServeEnv]:
     """
     A context manager that instantiates a serve environment for a given
