@@ -11,30 +11,31 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-from typing import List, Iterator, Callable, Optional
 from pathlib import Path
+from typing import Iterator, List, Optional
 
 import numpy as np
 import torch
 import torch.nn as nn
 
 from gluonts.core.serde import dump_json, load_json
-from gluonts.dataset.common import DataEntry, Dataset
+from gluonts.dataset.common import Dataset
 from gluonts.dataset.loader import InferenceDataLoader
 from gluonts.model.forecast import Forecast
 from gluonts.model.forecast_generator import (
+    ForecastGenerator,
     SampleForecastGenerator,
     predict_to_numpy,
 )
-from gluonts.torch.component import equals
 from gluonts.model.predictor import OutputTransform, Predictor
 from gluonts.torch.batchify import batchify
+from gluonts.torch.component import equals
 from gluonts.transform import Transformation
 
 
 @predict_to_numpy.register(nn.Module)
 def _(prediction_net: nn.Module, inputs: torch.Tensor) -> np.ndarray:
-    return prediction_net(*inputs).data.numpy()
+    return prediction_net(*inputs).cpu().numpy()
 
 
 class PyTorchPredictor(Predictor):
@@ -45,20 +46,26 @@ class PyTorchPredictor(Predictor):
         batch_size: int,
         prediction_length: int,
         freq: str,
-        device: torch.device,
         input_transform: Transformation,
-        forecast_generator: SampleForecastGenerator = SampleForecastGenerator(),
+        forecast_generator: ForecastGenerator = SampleForecastGenerator(),
         output_transform: Optional[OutputTransform] = None,
+        lead_time: int = 0,
+        device: Optional[torch.device] = torch.device("cpu"),
     ) -> None:
-        super().__init__(prediction_length, freq)
+        super().__init__(prediction_length, freq=freq, lead_time=lead_time)
         self.input_names = input_names
-        self.prediction_net = prediction_net
+        self.prediction_net = prediction_net.to(device)
         self.batch_size = batch_size
         self.input_transform = input_transform
         self.forecast_generator = forecast_generator
         self.output_transform = output_transform
         self.device = device
 
+    def to(self, device) -> "PyTorchPredictor":
+        self.prediction_net = self.prediction_net.to(device)
+        self.device = device
+        return self
+
     def predict(
         self, dataset: Dataset, num_samples: Optional[int] = None
     ) -> Iterator[Forecast]:
@@ -85,9 +92,8 @@ class PyTorchPredictor(Predictor):
         if type(self) != type(that):
             return False
 
-        # TODO: also consider equality of the pipelines
-        # if not equals(self.input_transform, that.input_transform):
-        #    return False
+        if not equals(self.input_transform, that.input_transform):
+            return False
 
         return equals(
             self.prediction_net.state_dict(),
@@ -98,7 +104,7 @@ class PyTorchPredictor(Predictor):
         super().serialize(path)
 
         # serialize network
-        with (path / f"prediction_net.json").open("w") as fp:
+        with (path / "prediction_net.json").open("w") as fp:
             print(dump_json(self.prediction_net), file=fp)
         torch.save(
             self.prediction_net.state_dict(), path / "prediction_net_state"
@@ -116,6 +122,7 @@ class PyTorchPredictor(Predictor):
                 batch_size=self.batch_size,
                 prediction_length=self.prediction_length,
                 freq=self.freq,
+                lead_time=self.lead_time,
                 forecast_generator=self.forecast_generator,
                 input_names=self.input_names,
             )
@@ -134,10 +141,10 @@ class PyTorchPredictor(Predictor):
             transformation = load_json(fp.read())
 
         # deserialize network
-        with (path / f"prediction_net.json").open("r") as fp:
+        with (path / "prediction_net.json").open("r") as fp:
             prediction_net = load_json(fp.read())
         prediction_net.load_state_dict(
-            torch.load(path / "prediction_net_state")
+            torch.load(path / "prediction_net_state", map_location=device)
         )
 
         parameters["device"] = device
