@@ -11,14 +11,13 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Standard library imports
 import abc
 from typing import Callable, Iterable, Iterator, List
 
-# First-party imports
+from gluonts.core.component import equals
 from gluonts.core.component import validated
-from gluonts.dataset.common import DataEntry
-from gluonts.runtime_params import GLUONTS_MAX_IDLE_TRANSFORMS
+from gluonts.dataset.common import DataEntry, Dataset
+from gluonts.env import env
 
 
 class Transformation(metaclass=abc.ABCMeta):
@@ -31,7 +30,7 @@ class Transformation(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def __call__(
         self, data_it: Iterable[DataEntry], is_train: bool
-    ) -> Iterator[DataEntry]:
+    ) -> Iterable[DataEntry]:
         pass
 
     def chain(self, other: "Transformation") -> "Chain":
@@ -40,6 +39,11 @@ class Transformation(metaclass=abc.ABCMeta):
     def __add__(self, other: "Transformation") -> "Chain":
         return self.chain(other)
 
+    def apply(
+        self, dataset: Dataset, is_train: bool = True
+    ) -> "TransformedDataset":
+        return TransformedDataset(dataset, self, is_train=is_train)
+
 
 class Chain(Transformation):
     """
@@ -48,7 +52,7 @@ class Chain(Transformation):
 
     @validated()
     def __init__(self, trans: List[Transformation]) -> None:
-        self.transformations = []
+        self.transformations: List[Transformation] = []
         for transformation in trans:
             # flatten chains
             if isinstance(transformation, Chain):
@@ -58,17 +62,54 @@ class Chain(Transformation):
 
     def __call__(
         self, data_it: Iterable[DataEntry], is_train: bool
-    ) -> Iterator[DataEntry]:
+    ) -> Iterable[DataEntry]:
         tmp = data_it
         for t in self.transformations:
             tmp = t(tmp, is_train)
         return tmp
 
 
+class TransformedDataset(Dataset):
+    """
+    A dataset that corresponds to applying a list of transformations to each
+    element in the base_dataset.
+    This only supports SimpleTransformations, which do the same thing at
+    prediction and training time.
+
+
+    Parameters
+    ----------
+    base_dataset
+        Dataset to transform
+    transformations
+        List of transformations to apply
+    """
+
+    def __init__(
+        self,
+        base_dataset: Dataset,
+        transformation: Transformation,
+        is_train=True,
+    ) -> None:
+        self.base_dataset = base_dataset
+        self.transformation = transformation
+        self.is_train = is_train
+
+    def __len__(self):
+        # NOTE this is unsafe when transformations are run with is_train = True
+        # since some transformations may not be deterministic (instance splitter)
+        return sum(1 for _ in self)
+
+    def __iter__(self) -> Iterator[DataEntry]:
+        yield from self.transformation(
+            self.base_dataset, is_train=self.is_train
+        )
+
+
 class Identity(Transformation):
     def __call__(
         self, data_it: Iterable[DataEntry], is_train: bool
-    ) -> Iterator[DataEntry]:
+    ) -> Iterable[DataEntry]:
         return data_it
 
 
@@ -121,31 +162,30 @@ class AdhocTransform(SimpleTransformation):
 
 class FlatMapTransformation(Transformation):
     """
-    Transformations that yield zero or more results per input, but do not combine
-    elements from the input stream.
+    Transformations that yield zero or more results per input, but do not
+    combine elements from the input stream.
     """
 
+    @validated()
+    def __init__(self):
+        self.max_idle_transforms = max(env.max_idle_transforms, 100)
+
     def __call__(
         self, data_it: Iterable[DataEntry], is_train: bool
     ) -> Iterator:
         num_idle_transforms = 0
         for data_entry in data_it:
             num_idle_transforms += 1
-            try:
-                for result in self.flatmap_transform(
-                    data_entry.copy(), is_train
-                ):
-                    num_idle_transforms = 0
-                    yield result
-            except Exception as e:
-                raise e
-            if num_idle_transforms > GLUONTS_MAX_IDLE_TRANSFORMS:
+            for result in self.flatmap_transform(data_entry.copy(), is_train):
+                num_idle_transforms = 0
+                yield result
+            if num_idle_transforms > self.max_idle_transforms:
                 raise Exception(
                     f"Reached maximum number of idle transformation calls.\n"
                     f"This means the transformation looped over "
-                    f"GLUONTS_MAX_IDLE_TRANSFORMS={GLUONTS_MAX_IDLE_TRANSFORMS} "
-                    f"inputs without returning any output.\n"
-                    f"This occurred in the following transformation:\n{self}"
+                    f"{self.max_idle_transforms} inputs without returning any "
+                    f"output.\nThis occurred in the following transformation:\n"
+                    f"{self}"
                 )
 
     @abc.abstractmethod
@@ -157,6 +197,7 @@ class FlatMapTransformation(Transformation):
 
 class FilterTransformation(FlatMapTransformation):
     def __init__(self, condition: Callable[[DataEntry], bool]) -> None:
+        super().__init__()
         self.condition = condition
 
     def flatmap_transform(
@@ -164,3 +205,16 @@ class FilterTransformation(FlatMapTransformation):
     ) -> Iterator[DataEntry]:
         if self.condition(data):
             yield data
+
+
+# The __init__ in FilterTransformation is not validated but
+# the __init__ in the parent class (FlatMapTransformation) is.
+# So now the code (equals_default_impl) validate the arguments in FilterTransformation,
+# which is an empty dict for all the FilterTransformation.
+# We can not make __init__ FilterTransformation as validated as
+# we may use lambda function as the argument
+@equals.register(FilterTransformation)
+def equals_filter_transformation(
+    this: FilterTransformation, that: FilterTransformation
+):
+    return this.condition.__code__.co_code == that.condition.__code__.co_code
