@@ -11,14 +11,13 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-from typing import Iterator, List, Optional, Tuple
+from typing import Iterator, List, Optional, Tuple, Type
 
 import numpy as np
 
-from gluonts.core.component import DType, validated, tensor_to_numpy
-from gluonts.core.exception import assert_data_error
+from gluonts.core.component import validated, tensor_to_numpy
 from gluonts.dataset.common import DataEntry
-from gluonts.support.util import erf, erfinv
+from gluonts.exceptions import assert_data_error
 
 from ._base import (
     FlatMapTransformation,
@@ -27,6 +26,82 @@ from ._base import (
 )
 
 
+def erf(x: np.ndarray) -> np.ndarray:
+    # Using numerical recipes approximation for erf function
+    # accurate to 1E-7
+
+    ones = np.ones_like(x)
+    zeros = np.zeros_like(x)
+
+    t = ones / (ones + 0.5 * np.abs(x))
+
+    coefficients = [
+        1.00002368,
+        0.37409196,
+        0.09678418,
+        -0.18628806,
+        0.27886807,
+        -1.13520398,
+        1.48851587,
+        -0.82215223,
+        0.17087277,
+    ]
+
+    inner = zeros
+    for c in coefficients[::-1]:
+        inner = t * (c + inner)
+
+    res = ones - t * np.exp((inner - 1.26551223 - np.square(x)))
+    return np.where(x >= zeros, res, -1.0 * res)
+
+
+def erfinv(x: np.ndarray) -> np.ndarray:
+    zeros = np.zeros_like(x)
+
+    w = -np.log((1.0 - x) * (1.0 + x))
+    mask_lesser = w < (zeros + 5.0)
+
+    w = np.where(mask_lesser, w - 2.5, np.sqrt(w) - 3.0)
+
+    coefficients_lesser = [
+        2.81022636e-08,
+        3.43273939e-07,
+        -3.5233877e-06,
+        -4.39150654e-06,
+        0.00021858087,
+        -0.00125372503,
+        -0.00417768164,
+        0.246640727,
+        1.50140941,
+    ]
+
+    coefficients_greater_equal = [
+        -0.000200214257,
+        0.000100950558,
+        0.00134934322,
+        -0.00367342844,
+        0.00573950773,
+        -0.0076224613,
+        0.00943887047,
+        1.00167406,
+        2.83297682,
+    ]
+
+    p = np.where(
+        mask_lesser,
+        coefficients_lesser[0] + zeros,
+        coefficients_greater_equal[0] + zeros,
+    )
+
+    for c_l, c_ge in zip(
+        coefficients_lesser[1:], coefficients_greater_equal[1:]
+    ):
+        c = np.where(mask_lesser, c_l + zeros, c_ge + zeros)
+        p = c + p * w
+
+    return p * x
+
+
 class AsNumpyArray(SimpleTransformation):
     """
     Converts the value of a field into a numpy array.
@@ -42,7 +117,7 @@ class AsNumpyArray(SimpleTransformation):
 
     @validated()
     def __init__(
-        self, field: str, expected_ndim: int, dtype: DType = np.float32
+        self, field: str, expected_ndim: int, dtype: Type = np.float32
     ) -> None:
         self.field = field
         self.expected_ndim = expected_ndim
@@ -285,6 +360,8 @@ class SampleTargetDim(FlatMapTransformation):
         num_samples: int,
         shuffle: bool = True,
     ) -> None:
+        super().__init__()
+
         self.field_name = field_name
         self.target_field = target_field
         self.observed_values_field = observed_values_field
@@ -337,7 +414,7 @@ class CDFtoGaussianTransform(MapTransformation):
         observed_values_field: str,
         cdf_suffix="_cdf",
         max_context_length: Optional[int] = None,
-        dtype: DType = np.float32,
+        dtype: Type = np.float32,
     ) -> None:
         """
         Constructor for CDFtoGaussianTransform.
@@ -469,13 +546,10 @@ class CDFtoGaussianTransform(MapTransformation):
         sorted_target = data[self.sort_target_field]
         sorted_target_length, target_dim = sorted_target.shape
 
-        quantiles = (
-            np.stack(
-                [np.arange(sorted_target_length) for _ in range(target_dim)],
-                axis=1,
-            )
-            / float(sorted_target_length)
-        )
+        quantiles = np.stack(
+            [np.arange(sorted_target_length) for _ in range(target_dim)],
+            axis=1,
+        ) / float(sorted_target_length)
 
         x_diff = np.diff(sorted_target, axis=0)
         y_diff = np.diff(quantiles, axis=0)
@@ -534,7 +608,7 @@ class CDFtoGaussianTransform(MapTransformation):
         return quantiles
 
     @staticmethod
-    def _add_noise(x: np.array) -> np.array:
+    def _add_noise(x: np.ndarray) -> np.ndarray:
         scale_noise = 0.2
         std = np.sqrt(
             (np.square(x - x.mean(axis=1, keepdims=True))).mean(
@@ -549,8 +623,8 @@ class CDFtoGaussianTransform(MapTransformation):
 
     @staticmethod
     def _search_sorted(
-        sorted_vec: np.array, to_insert_vec: np.array
-    ) -> np.array:
+        sorted_vec: np.ndarray, to_insert_vec: np.ndarray
+    ) -> np.ndarray:
         """
         Finds the indices of the active piece-wise linear function.
 
@@ -580,11 +654,11 @@ class CDFtoGaussianTransform(MapTransformation):
 
     def _forward_transform(
         self,
-        sorted_vec: np.array,
-        target: np.array,
-        slopes: np.array,
-        intercepts: np.array,
-    ) -> np.array:
+        sorted_vec: np.ndarray,
+        target: np.ndarray,
+        slopes: np.ndarray,
+        intercepts: np.ndarray,
+    ) -> np.ndarray:
         """
         Applies the forward transformation to the marginals of the multivariate
         target. Target (real valued) -> empirical cdf [0, 1]
@@ -606,29 +680,29 @@ class CDFtoGaussianTransform(MapTransformation):
             Transformed target vector.
         """
         transformed = list()
-        for sorted, t, slope, intercept in zip(
+        for sorted_vector, t, slope, intercept in zip(
             sorted_vec.transpose(),
             target.transpose(),
             slopes.transpose(),
             intercepts.transpose(),
         ):
-            indices = self._search_sorted(sorted, t)
+            indices = self._search_sorted(sorted_vector, t)
             transformed_value = slope[indices] * t + intercept[indices]
             transformed.append(transformed_value)
         return np.array(transformed).transpose()
 
     @staticmethod
-    def standard_gaussian_cdf(x: np.array) -> np.array:
+    def standard_gaussian_cdf(x: np.ndarray) -> np.ndarray:
         u = x / (np.sqrt(2.0))
         return (erf(u) + 1.0) / 2.0
 
     @staticmethod
-    def standard_gaussian_ppf(y: np.array) -> np.array:
+    def standard_gaussian_ppf(y: np.ndarray) -> np.ndarray:
         y_clipped = np.clip(y, a_min=1.0e-6, a_max=1.0 - 1.0e-6)
         return np.sqrt(2.0) * erfinv(2.0 * y_clipped - 1.0)
 
     @staticmethod
-    def winsorized_cutoff(m: np.array) -> np.array:
+    def winsorized_cutoff(m: float) -> float:
         """
         Apply truncation to the empirical CDF estimator to reduce variance as
         described here: https://arxiv.org/abs/0903.0649
@@ -636,14 +710,14 @@ class CDFtoGaussianTransform(MapTransformation):
         Parameters
         ----------
         m
-            Input array with empirical CDF values.
+            Input empirical CDF value.
 
         Returns
         -------
         res
-            Truncated empirical CDf values.
+            Truncated empirical CDf value.
         """
-        res = 1 / (4 * m ** 0.25 * np.sqrt(3.14 * np.log(m)))
+        res = 1 / (4 * m**0.25 * np.sqrt(3.14 * np.log(m)))
         assert 0 < res < 1
         return res
 
@@ -729,12 +803,12 @@ def cdf_to_gaussian_forward_transform(
 
         """
 
-        batch_size, num_timesteps, target_dim = batch_target_sorted.shape
+        num_timesteps = batch_target_sorted.shape[1]
         indices = np.floor(batch_predictions * num_timesteps)
         # indices = indices - 1
         # for now project into [0, 1]
         indices = np.clip(indices, 0, num_timesteps - 1)
-        indices = indices.astype(np.int)
+        indices = indices.astype(int)
 
         transformed = np.where(
             np.take_along_axis(slopes, indices, axis=1) != 0.0,
@@ -748,7 +822,7 @@ def cdf_to_gaussian_forward_transform(
         return transformed
 
     # applies inverse cdf to all outputs
-    batch_size, samples, target_dim, time = outputs.shape
+    samples = outputs.shape[1]
     for sample_index in range(0, samples):
         outputs[:, sample_index, :, :] = _empirical_cdf_inverse_transform(
             tensor_to_numpy(input_batch["past_target_sorted"]),
@@ -759,3 +833,69 @@ def cdf_to_gaussian_forward_transform(
             tensor_to_numpy(input_batch["intercepts"]),
         )
     return outputs
+
+
+class ToIntervalSizeFormat(FlatMapTransformation):
+    """
+    Convert a sparse univariate time series to the `interval-size` format,
+    i.e., a two dimensional time series where the first dimension corresponds
+    to the time since last positive value (1-indexed), and the second dimension
+    corresponds to the size of the demand. This format is used often in the
+    intermittent demand literature, where predictions are performed on this
+    "dense" time series, e.g., as in Croston's method.
+
+    As an example, the time series `[0, 0, 1, 0, 3, 2, 0, 4]` is converted into
+    the 2-dimensional time series `[[3, 2, 1, 2], [1, 3, 2, 4]]`, with a
+    shape (2, M) where M denotes the number of non-zero items in the time series.
+
+    Parameters
+    ----------
+    target_field
+        The target field to be converted, containing a univariate and sparse
+        time series
+    drop_empty
+        If True, all-zero time series will be dropped.
+    discard_first
+        If True, the first element in the converted dense series will be dropped,
+        replacing the target with a (2, M-1) tet instead. This can be used
+        when the first 'inter-demand' time is not well-defined. e.g., when the true
+        starting index of the time-series is not known.
+    """
+
+    @validated()
+    def __init__(
+        self,
+        target_field: str,
+        drop_empty: bool = False,
+        discard_first: bool = False,
+    ) -> None:
+        super().__init__()
+
+        self.target_field = target_field
+        self.drop_empty = drop_empty
+        self.discard_first = discard_first
+
+    def _process_sparse_time_sample(self, a: List) -> Tuple[List, List]:
+        a: np.ndarray = np.array(a)
+        (non_zero_index,) = np.nonzero(a)
+
+        if len(non_zero_index) == 0:
+            return [], []
+
+        times = np.diff(non_zero_index, prepend=-1.0).tolist()
+        sizes = a[non_zero_index].tolist()
+
+        if self.discard_first:
+            return times[1:], sizes[1:]
+        return times, sizes
+
+    def flatmap_transform(
+        self, data: DataEntry, is_train: bool
+    ) -> Iterator[DataEntry]:
+        target = data[self.target_field]
+
+        times, sizes = self._process_sparse_time_sample(target)
+
+        if len(times) > 0 or not self.drop_empty:
+            data[self.target_field] = [times, sizes]
+            yield data
