@@ -11,17 +11,14 @@
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
 
-# Third-party imports
 from typing import Optional
 
-# Third-party imports
 import numpy as np
 import pandas as pd
 import pytest
 
-# First-party imports
-from gluonts.core.exception import GluonTSDataError
-from gluonts.dataset.common import Dataset, ListDataset, DataEntry
+from gluonts.dataset.common import DataEntry, Dataset, ListDataset
+from gluonts.exceptions import GluonTSDataError
 from gluonts.model.npts import KernelType, NPTSPredictor
 from gluonts.model.npts._weighted_sampler import WeightedSampler
 
@@ -585,7 +582,7 @@ def _inject_nans_in_target(data_entry: DataEntry, p: float) -> DataEntry:
     """
     nan_positions = np.sort(
         a=np.random.choice(
-            a=np.arange(data_entry["target"].size, dtype=np.int),
+            a=np.arange(data_entry["target"].size, dtype=int),
             size=int(p * data_entry["target"].size),
             replace=False,
         )
